# qbt-helper

This program helps me add torrents from URLs to a running qBittorrent instance.

## Installation

``` shell
pipx install qbt-helper
```

## Usage

``` shell
Usage:
    qbt-helper (HOSTNAME) (USERNAME) (PASSWORD)
    qbt-helper -h
    
Examples:
    qbt-helper "localhost:8080" "admin" "adminadmin"
    qbt-helper "https://cat.seedhost.eu/lol/qbittorrent" "lol" "meow"
    
Options:
    -h, --help  show this help message and exit
```
